@@ -20,10 +20,10 @@
 # you're warned :)
 
 # quickly version used for project format compatibility
-__version__ = '0.6.1'
+__version__ = '11.04'
 
 # where quickly will head for quickly data (for instance, templates)
 # by default, this is ../data, relative to trunk layout
-__quickly_data_directory__ = '../data/'
+__quickly_data_directory__ = '../data'
 
 
